@@ -1,6 +1,6 @@
 """PBX object types"""
 
-from typing import Optional
+from typing import List, Optional
 
 import deserialize
 
@@ -37,24 +37,23 @@ class PBXContainerItemProxy(PBXObject):
     remote_info: str
 
 
-@deserialize.auto_snake()
-@deserialize.downcast_identifier(PBXObject, "PBXReferenceProxy")
-class PBXReferenceProxy(PBXObject):
-    """Represents a PBXReferenceProxy.
-
-    It's not clear what this one is. As far as I can tell, it references
-    something in another project in the same workspace.
-    """
-
-    file_type: str
-    path: str
-    remote_ref: str
-    source_tree: str
-
-
 @deserialize.auto_snake()
 class ProjectReference:
     """A reference to another project."""
 
     product_group: str
     project_ref: str
+
+
+@deserialize.auto_snake()
+@deserialize.key("membership_exceptions", "membershipExceptions")
+@deserialize.downcast_identifier(PBXObject, "PBXFileSystemSynchronizedBuildFileExceptionSet")
+class PBXFileSystemSynchronizedBuildFileExceptionSet(PBXObject):
+    """Represents a PBXFileSystemSynchronizedBuildFileExceptionSet.
+
+    A new feature in Xcode 16. It follows a group of files on disk to try and
+    reduce merge conflicts in the pbxproj.
+    """
+
+    membership_exceptions: List[str]
+    target: str
